        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 29 <strong>control</strong><br>0,1,2,3,4,6,7,9,10,11,13,14,17,21,23,24,25,27,29,31,32,33,36,38,41,43,45,47,49';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260530 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 22 <br>5,8,12,15,16,18,19,20,22,26,28,30,34,35,37,39,40,42,44,46,48,50';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260530 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260530 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 29 <strong>control</strong><br>0,1,2,3,4,6,7,9,10,11,13,14,17,21,23,24,25,27,29,31,32,33,36,38,41,43,45,47,49';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260530 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 22 <br>5,8,12,15,16,18,19,20,22,26,28,30,34,35,37,39,40,42,44,46,48,50';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260530 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260530 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 29 <strong>control</strong><br>0,1,2,3,4,6,7,9,10,11,13,14,17,21,23,24,25,27,29,31,32,33,36,38,41,43,45,47,49';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260530 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 22 <br>5,8,12,15,16,18,19,20,22,26,28,30,34,35,37,39,40,42,44,46,48,50';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260530 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260530 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 29 <strong>control</strong><br>0,1,2,3,4,6,7,9,10,11,13,14,17,21,23,24,25,27,29,31,32,33,36,38,41,43,45,47,49';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260530 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 22 <br>5,8,12,15,16,18,19,20,22,26,28,30,34,35,37,39,40,42,44,46,48,50';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260530 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260530 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 29 <strong>control</strong><br>0,1,2,3,4,6,7,9,10,11,13,14,17,21,23,24,25,27,29,31,32,33,36,38,41,43,45,47,49';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260530 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>12</strong> miembros: 22 <br>5,8,12,15,16,18,19,20,22,26,28,30,34,35,37,39,40,42,44,46,48,50';}
}
